/******************************************************************************
 *  Copyright 2005 by Texas Instruments Japan Limited.
 *  All rights reserved. Property of Texas Instruments Japan Limited.
 *  Duplicate or disclose this code are granted through contract.
 *  
 *  THE PROGRAMS ARE PROVIDED "AS IS". TIJ MAKES NO WARRANTIES OR
 *  REPRESENTATIONS, EITHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING ANY
 *  IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE,
 *  LACK OF VIRUSES, ACCURACY OR COMPLETENESS OF RESPONSES, RESULTS AND LACK OF
 *  NEGLIGENCE. TIJ DISCLAIMS ANY WARRANTY OF TITLE, QUIET ENJOYMENT, QUIET
 *  POSSESSION, AND NON-INFRINGEMENT OF ANY THIRD PARTY INTELLECTUAL PROPERTY
 *  RIGHTS WITH REGARD TO THE PROGRAMS OR YOUR USE OF THOSE PROGRAMS.
 *-----------------------------------------------------------------------------
 *
 ******************************************************************************/
/************************************************************/
/*     select c55x device                                   */
/************************************************************/
/************************************************************/

#define VC5502  	 0		/*set "1" if target device is C5502  */
#define VC5509A 	 1		/*set "1" if target device is C5509A */
#define VC5510  	 0		/*set "1" if target device is C5510  */


#define VC5501  	 0		/*set "1" if target device is C5501  */
#define VC5503  	 0		/*set "1" if target device is C5503  */
#define VC5507  	 0		/*set "1" if target device is C5507  */

/************************************************************/
/************************************************************/
/*     CPU register                                         */
/************************************************************/
/************************************************************/
// interrupt 
#define IER0 		 (*(volatile unsigned int *)0x0000)
#define IFR0 		 (*(volatile unsigned int *)0x0001)
#define IER1 		 (*(volatile unsigned int *)0x0045)
#define IFR1 		 (*(volatile unsigned int *)0x0046)
#define IVPD 		 (*(volatile unsigned int *)0x0049)
#define IVPH 		 (*(volatile unsigned int *)0x004a)


/*
=====================================
===== IFR0/IER0 interrupt table =====
=====================================
--------+----------+-------------+----------+----------+------------+---------+
IFR0    | C5501    | C5502       | C5503    | C5507    | C5509A     | C5510   |
--------+----------+-------------+----------+----------+------------+---------+
0x0001  | -        | -           | -        | -        | -          | -       |
0x0002  | -        | -           | -        | -        | -          | -       |
0x0004  | INT0     | INT0        | INT0     | INT0     | INT0       | INT0    |
0x0008  | INT2     | INT2        | INT2     | INT2     | INT2       | INT2    |
0x0010  | TINT0    | TINT0       | TINT0    | TINT0    | TINT0      | TINT0   |
0x0020  | RINT0    | RINT0       | RINT0    | RINT0    | RINT0      | RINT0   |
0x0040  | RINT1    | RINT1       | RINT1    | RINT1    | RINT1      | RINT1   |
0x0080  | XINT1    | XINT1       | XINT1    | XINT1    | XINT1/MMC1 | XINT1   |
0x0100  | -        | -           | -        | USB      | USB        | -       |
0x0200  | DMA1     | DMA1        | DMA1     | DMA1     | DMA1       | DMA1    |
0x0400  | DSPINT   | DSPINT      | DSPINT   | DSPINT   | DSPINT     | DSPIN   |
0x0800  | INT3/WDT | INT3/WDT    | INT3/WDT | INT3/WDT | INT3/WDT   | INT3    |
0x1000  | UART     | RINT2/UART  | RINT2    | RINT2    | RINT2      | RINT2   |
0x2000  | -        | XINT2       | XINT2    | XINT2    | XINT2/MMC2 | XINT2   |
0x4000  | DMA4     | DMA4        | DMA4     | DMA4     | DMA4       | DMA4    |
0x8000  | DMA5     | DMA5        | DMA5     | DMA5     | DMA5       | DMA5    |
--------+----------+-------------+----------+----------+------------+---------+
*/
#define INT0_FLAG	 0x0004
#define	INT2_FLAG	 0x0008
#define	TINT0_FLAG	 0x0010
#define RINT0_FLAG	 0x0020
#define RINT1_FLAG	 0x0040
#define XINT1_FLAG	 0x0080
#define DMA1_FLAG	 0x0200
#define DSPINT_FLAG	 0x0400
#define INT3_FLAG	 0x0800
#define DMA4_FLAG	 0x4000
#define DMA5_FLAG	 0x8000

#if (VC5509A)
#define MMC1_FLAG	 0x0080 	// XINT1/MMC1
#define MMC2_FLAG	 0x2000 	// XINT2/MMC2
#endif 
#if (VC5507 || VC5509A)
#define USB_FLAG	 0x0100
#endif 
#if (VC5501 || VC5502 || VC5503 || VC5507 || VC5509A)
#define WDTINT_FLAG	 0x0800		//INT3/WDT
#endif 
#if (VC5501 || VC5502)
#define UART_FLAG	 0x1000		//RINT2/URT
#endif
#if (VC5502 || VC5503 || VC5507 || VC5509A || VC5510)
#define RINT2_FLAG	 0x1000
#define XINT2_FLAG	 0x2000
#endif 

/*
=====================================
===== IFR1/IER1 interrupt table =====
=====================================
--------+----------+-------------+----------+----------+------------+---------+
IFR1    | C5501    | C5502       | C5503    | C5507    | C5509A     | C5510   |
--------+----------+-------------+----------+----------+------------+---------+
0x0001  | INT1     | INT1        | INT1     | INT1     | INT1       | INT1    |
0x0002  | XINT0    | XINT0       | XINT0    | XINT0    | XINT0      | XINT0   |
0x0004  | DMA0     | DMA0        | DMA0     | DMA0     | DMA0       | DMA0    |
0x0008  | INT4     | INT4        | INT4/RTC | INT4/RTC | INT4/RTC   | INT4    |
0x0010  | DMA2     | DMA2        | DMA2     | DMA2     | DMA2       | DMA2    |
0x0020  | DMA3     | DMA3        | DMA3     | DMA3     | DMA3       | DMA3    |
0x0040  | TINT1    | TINT1       | TINT1    | TINT1    | TINT1      | TINT1   |
0x0080  | I2C      | I2C         | I2C      | I2C      | I2C        | INT5    |
0x0100  | BERR     | BERR        | BERR     | BERR     | BERR       | BERR    |
0x0200  | DLOG     | DLOG        | DLOG     | DLOG     | DLOG       | DLOG    |
0x0400  | RTOS     | RTOS        | RTOS     | RTOS     | RTOS       | RTOS    |
0x0800  | -        | -           | -        | -        | -          | -       |
0x1000  | -        | -           | -        | -        | -          | -       |
0x2000  | -        | -           | -        | -        | -          | -       |
0x4000  | -        | -           | -        | -        | -          | -       |
0x8000  | -        | -           | -        | -        | -          | -       |
--------+----------+-------------+----------+----------+------------+---------+
*/

#define INT1_FLAG	 0x0001
#define XINT0_FLAG	 0x0002
#define DMA0_FLAG	 0x0004
#define INT4_FLAG	 0x0008
#define DMA2_FLAG	 0x0010
#define DMA3_FLAG	 0x0020
#define TINT1_FLAG	 0x0040

#if (VC5503 || VC5507 || VC5509A)
#define RTCINT_FLAG	 0x0008	//INT4/RTC
#endif
#if (VC5510)
#define INT5_FLAG	 0x0080
#endif
#if (VC5501 || VC5502 || VC5503 || VC5507 || VC5509A)
#define I2C_FLAG	 0x0080
#endif

/************************************************************/
/************************************************************/
/*     Peripheral register                                  */
/************************************************************/
/************************************************************/
/*----------------------------------------------------------
 * McBSP registers
 *----------------------------------------------------------*/
/*----------------------------*/
/*----- VC5503/07/09A/10 -----*/
/*----------------------------*/
#if (VC5503 || VC5507 || VC5509A || VC5510)
/*--- McBSP0 ---*/
#define DRR20		 (*(ioport volatile unsigned int *)0x2800)
#define DRR10		 (*(ioport volatile unsigned int *)0x2801)
#define DXR20		 (*(ioport volatile unsigned int *)0x2802)
#define DXR10		 (*(ioport volatile unsigned int *)0x2803)
#define SPCR20		 (*(ioport volatile unsigned int *)0x2804)
#define SPCR10		 (*(ioport volatile unsigned int *)0x2805)
#define RCR20		 (*(ioport volatile unsigned int *)0x2806)
#define RCR10		 (*(ioport volatile unsigned int *)0x2807)
#define XCR20		 (*(ioport volatile unsigned int *)0x2808)
#define XCR10		 (*(ioport volatile unsigned int *)0x2809)
#define SRGR20		 (*(ioport volatile unsigned int *)0x280A)
#define SRGR10		 (*(ioport volatile unsigned int *)0x280B)
#define MCR20		 (*(ioport volatile unsigned int *)0x280C)
#define MCR10		 (*(ioport volatile unsigned int *)0x280D)
#define RCERA0		 (*(ioport volatile unsigned int *)0x280E)
#define RCERB0		 (*(ioport volatile unsigned int *)0x280F)
#define XCERA0		 (*(ioport volatile unsigned int *)0x2810)
#define XCERB0		 (*(ioport volatile unsigned int *)0x2811)
#define PCR0		 (*(ioport volatile unsigned int *)0x2812)
#define RCERC0		 (*(ioport volatile unsigned int *)0x2813)
#define RCERD0		 (*(ioport volatile unsigned int *)0x2814)
#define XCERC0		 (*(ioport volatile unsigned int *)0x2815)
#define XCERD0		 (*(ioport volatile unsigned int *)0x2816)
#define RCERE0		 (*(ioport volatile unsigned int *)0x2817)
#define RCERF0		 (*(ioport volatile unsigned int *)0x2818)
#define XCERE0		 (*(ioport volatile unsigned int *)0x2819)
#define XCERF0  	 (*(ioport volatile unsigned int *)0x281A)
#define RCERG0  	 (*(ioport volatile unsigned int *)0x281B)
#define RCERH0  	 (*(ioport volatile unsigned int *)0x281C)
#define XCERG0  	 (*(ioport volatile unsigned int *)0x281D)
#define XCERH0  	 (*(ioport volatile unsigned int *)0x281E)

#define	DRR20_ADDR	 0x002800
#define	DRR10_ADDR	 0x002801
#define	DXR20_ADDR	 0x002802
#define	DXR10_ADDR	 0x002803
                
/*--- McBSP1 ---*/
#define DRR21		 (*(ioport volatile unsigned int *)0x2C00)
#define DRR11		 (*(ioport volatile unsigned int *)0x2C01)
#define DXR21		 (*(ioport volatile unsigned int *)0x2C02)
#define DXR11		 (*(ioport volatile unsigned int *)0x2C03)
#define SPCR21		 (*(ioport volatile unsigned int *)0x2C04)
#define SPCR11		 (*(ioport volatile unsigned int *)0x2C05)
#define RCR21		 (*(ioport volatile unsigned int *)0x2C06)
#define RCR11		 (*(ioport volatile unsigned int *)0x2C07)
#define XCR21		 (*(ioport volatile unsigned int *)0x2C08)
#define XCR11		 (*(ioport volatile unsigned int *)0x2C09)
#define SRGR21		 (*(ioport volatile unsigned int *)0x2C0A)
#define SRGR11		 (*(ioport volatile unsigned int *)0x2C0B)
#define MCR21		 (*(ioport volatile unsigned int *)0x2C0C)
#define MCR11		 (*(ioport volatile unsigned int *)0x2C0D)
#define RCERA1		 (*(ioport volatile unsigned int *)0x2C0E)
#define RCERB1		 (*(ioport volatile unsigned int *)0x2C0F)
#define XCERA1		 (*(ioport volatile unsigned int *)0x2C10)
#define XCERB1		 (*(ioport volatile unsigned int *)0x2C11)
#define PCR1 		 (*(ioport volatile unsigned int *)0x2C12)
#define RCERC1  	 (*(ioport volatile unsigned int *)0x2C13)
#define RCERD1  	 (*(ioport volatile unsigned int *)0x2C14)
#define XCERC1  	 (*(ioport volatile unsigned int *)0x2C15)
#define XCERD1  	 (*(ioport volatile unsigned int *)0x2C16)
#define RCERE1  	 (*(ioport volatile unsigned int *)0x2C17)
#define RCERF1  	 (*(ioport volatile unsigned int *)0x2C18)
#define XCERE1  	 (*(ioport volatile unsigned int *)0x2C19)
#define XCERF1  	 (*(ioport volatile unsigned int *)0x2C1A)
#define RCERG1  	 (*(ioport volatile unsigned int *)0x2C1B)
#define RCERH1  	 (*(ioport volatile unsigned int *)0x2C1C)
#define XCERG1  	 (*(ioport volatile unsigned int *)0x2C1D)
#define XCERH1  	 (*(ioport volatile unsigned int *)0x2C1E)

#define	DRR21_ADDR	 0x002c00
#define	DRR11_ADDR	 0x002c01
#define	DXR21_ADDR	 0x002c02
#define	DXR11_ADDR	 0x002c03

/*--- McBSP2 ---*/
#define DRR22		 (*(ioport volatile unsigned int *)0x3000)
#define DRR12		 (*(ioport volatile unsigned int *)0x3001)
#define DXR22		 (*(ioport volatile unsigned int *)0x3002)
#define DXR12		 (*(ioport volatile unsigned int *)0x3003)
#define SPCR22		 (*(ioport volatile unsigned int *)0x3004)
#define SPCR12		 (*(ioport volatile unsigned int *)0x3005)
#define RCR22		 (*(ioport volatile unsigned int *)0x3006)
#define RCR12		 (*(ioport volatile unsigned int *)0x3007)
#define XCR22		 (*(ioport volatile unsigned int *)0x3008)
#define XCR12		 (*(ioport volatile unsigned int *)0x3009)
#define SRGR22		 (*(ioport volatile unsigned int *)0x300A)
#define SRGR12		 (*(ioport volatile unsigned int *)0x300B)
#define MCR22		 (*(ioport volatile unsigned int *)0x300C)
#define MCR12		 (*(ioport volatile unsigned int *)0x300D)
#define RCERA2		 (*(ioport volatile unsigned int *)0x300E)
#define RCERB2		 (*(ioport volatile unsigned int *)0x300F)
#define XCERA2		 (*(ioport volatile unsigned int *)0x3010)
#define XCERB2		 (*(ioport volatile unsigned int *)0x3011)
#define PCR2 		 (*(ioport volatile unsigned int *)0x3012)
#define RCERC2  	 (*(ioport volatile unsigned int *)0x3013)
#define RCERD2  	 (*(ioport volatile unsigned int *)0x3014)
#define XCERC2  	 (*(ioport volatile unsigned int *)0x3015)
#define XCERD2  	 (*(ioport volatile unsigned int *)0x3016)
#define RCERE2  	 (*(ioport volatile unsigned int *)0x3017)
#define RCERF2  	 (*(ioport volatile unsigned int *)0x3018)
#define XCERE2  	 (*(ioport volatile unsigned int *)0x3019)
#define XCERF2  	 (*(ioport volatile unsigned int *)0x301A)
#define RCERG2  	 (*(ioport volatile unsigned int *)0x301B)
#define RCERH2  	 (*(ioport volatile unsigned int *)0x301C)
#define XCERG2  	 (*(ioport volatile unsigned int *)0x301D)
#define XCERH2  	 (*(ioport volatile unsigned int *)0x301E)

#define	DRR22_ADDR	 0x003000
#define	DRR12_ADDR	 0x003001
#define	DXR22_ADDR	 0x003002
#define	DXR12_ADDR	 0x003003

#endif

/*---------------------*/
/*----- VC5501/02 -----*/
/*---------------------*/
#if (VC5501|| VC5502)
/*--- McBSP0 ---*/
#define DRR10		 (*(ioport volatile unsigned int *)0x2800)
#define DRR20		 (*(ioport volatile unsigned int *)0x2801)
#define DXR10		 (*(ioport volatile unsigned int *)0x2802)
#define DXR20		 (*(ioport volatile unsigned int *)0x2803)
#define SPCR10		 (*(ioport volatile unsigned int *)0x2804)
#define SPCR20		 (*(ioport volatile unsigned int *)0x2805)
#define RCR10		 (*(ioport volatile unsigned int *)0x2806)
#define RCR20		 (*(ioport volatile unsigned int *)0x2807)
#define XCR10		 (*(ioport volatile unsigned int *)0x2808)
#define XCR20		 (*(ioport volatile unsigned int *)0x2809)
#define SRGR10		 (*(ioport volatile unsigned int *)0x280A)
#define SRGR20		 (*(ioport volatile unsigned int *)0x280B)
#define MCR10		 (*(ioport volatile unsigned int *)0x280C)
#define MCR20		 (*(ioport volatile unsigned int *)0x280D)
#define RCERA0		 (*(ioport volatile unsigned int *)0x280E)
#define RCERB0		 (*(ioport volatile unsigned int *)0x280F)
#define XCERA0		 (*(ioport volatile unsigned int *)0x2810)
#define XCERB0		 (*(ioport volatile unsigned int *)0x2811)
#define PCR0		 (*(ioport volatile unsigned int *)0x2812)
#define RCERC0  	 (*(ioport volatile unsigned int *)0x2814)
#define RCERD0  	 (*(ioport volatile unsigned int *)0x2815)
#define XCERC0  	 (*(ioport volatile unsigned int *)0x2816)
#define XCERD0  	 (*(ioport volatile unsigned int *)0x2817)
#define RCERE0  	 (*(ioport volatile unsigned int *)0x2818)
#define RCERF0  	 (*(ioport volatile unsigned int *)0x2819)
#define XCERE0  	 (*(ioport volatile unsigned int *)0x281A)
#define XCERF0  	 (*(ioport volatile unsigned int *)0x281B)
#define RCERG0  	 (*(ioport volatile unsigned int *)0x281C)
#define RCERH0  	 (*(ioport volatile unsigned int *)0x281D)
#define XCERG0  	 (*(ioport volatile unsigned int *)0x281E)
#define XCERH0  	 (*(ioport volatile unsigned int *)0x281F)

#define	DRR10_ADDR	 0x002800
#define	DRR20_ADDR	 0x002801
#define	DXR10_ADDR	 0x002802
#define	DXR20_ADDR	 0x002803
                
/*--- McBSP1 ---*/
#define DRR11		 (*(ioport volatile unsigned int *)0x2C00)
#define DRR21		 (*(ioport volatile unsigned int *)0x2C01)
#define DXR11		 (*(ioport volatile unsigned int *)0x2C02)
#define DXR21		 (*(ioport volatile unsigned int *)0x2C03)
#define SPCR11		 (*(ioport volatile unsigned int *)0x2C04)
#define SPCR21		 (*(ioport volatile unsigned int *)0x2C05)
#define RCR11		 (*(ioport volatile unsigned int *)0x2C06)
#define RCR21		 (*(ioport volatile unsigned int *)0x2C07)
#define XCR11		 (*(ioport volatile unsigned int *)0x2C08)
#define XCR21		 (*(ioport volatile unsigned int *)0x2C09)
#define SRGR11		 (*(ioport volatile unsigned int *)0x2C0A)
#define SRGR21		 (*(ioport volatile unsigned int *)0x2C0B)
#define MCR11		 (*(ioport volatile unsigned int *)0x2C0C)
#define MCR21		 (*(ioport volatile unsigned int *)0x2C0D)
#define RCERA1		 (*(ioport volatile unsigned int *)0x2C0E)
#define RCERB1		 (*(ioport volatile unsigned int *)0x2C0F)
#define XCERA1		 (*(ioport volatile unsigned int *)0x2C10)
#define XCERB1		 (*(ioport volatile unsigned int *)0x2C11)
#define PCR1		 (*(ioport volatile unsigned int *)0x2C12)
#define RCERC1  	 (*(ioport volatile unsigned int *)0x2C14)
#define RCERD1  	 (*(ioport volatile unsigned int *)0x2C15)
#define XCERC1  	 (*(ioport volatile unsigned int *)0x2C16)
#define XCERD1  	 (*(ioport volatile unsigned int *)0x2C17)
#define RCERE1  	 (*(ioport volatile unsigned int *)0x2C18)
#define RCERF1  	 (*(ioport volatile unsigned int *)0x2C19)
#define XCERE1  	 (*(ioport volatile unsigned int *)0x2C1A)
#define XCERF1  	 (*(ioport volatile unsigned int *)0x2C1B)
#define RCERG1  	 (*(ioport volatile unsigned int *)0x2C1C)
#define RCERH1  	 (*(ioport volatile unsigned int *)0x2C1D)
#define XCERG1  	 (*(ioport volatile unsigned int *)0x2C1E)
#define XCERH1  	 (*(ioport volatile unsigned int *)0x2C1F)

#define	DRR11_ADDR	 0x002c00
#define	DRR21_ADDR	 0x002c01
#define	DXR11_ADDR	 0x002c02
#define	DXR21_ADDR	 0x002c03

#endif

#if (VC5502)
/*--- McBSP2 ---*/
#define DRR12		 (*(ioport volatile unsigned int *)0x3000)
#define DRR22		 (*(ioport volatile unsigned int *)0x3001)
#define DXR12		 (*(ioport volatile unsigned int *)0x3002)
#define DXR22		 (*(ioport volatile unsigned int *)0x3003)
#define SPCR12		 (*(ioport volatile unsigned int *)0x3004)
#define SPCR22		 (*(ioport volatile unsigned int *)0x3005)
#define RCR12		 (*(ioport volatile unsigned int *)0x3006)
#define RCR22		 (*(ioport volatile unsigned int *)0x3007)
#define XCR12		 (*(ioport volatile unsigned int *)0x3008)
#define XCR22		 (*(ioport volatile unsigned int *)0x3009)
#define SRGR12		 (*(ioport volatile unsigned int *)0x300A)
#define SRGR22		 (*(ioport volatile unsigned int *)0x300B)
#define MCR12		 (*(ioport volatile unsigned int *)0x300C)
#define MCR22		 (*(ioport volatile unsigned int *)0x300D)
#define RCERA2		 (*(ioport volatile unsigned int *)0x300E)
#define RCERB2		 (*(ioport volatile unsigned int *)0x300F)
#define XCERA2		 (*(ioport volatile unsigned int *)0x3010)
#define XCERB2		 (*(ioport volatile unsigned int *)0x3011)
#define PCR2		 (*(ioport volatile unsigned int *)0x3012)
#define RCERC2  	 (*(ioport volatile unsigned int *)0x3014)
#define RCERD2  	 (*(ioport volatile unsigned int *)0x3015)
#define XCERC2  	 (*(ioport volatile unsigned int *)0x3016)
#define XCERD2  	 (*(ioport volatile unsigned int *)0x3017)
#define RCERE2  	 (*(ioport volatile unsigned int *)0x3018)
#define RCERF2  	 (*(ioport volatile unsigned int *)0x3019)
#define XCERE2  	 (*(ioport volatile unsigned int *)0x301A)
#define XCERF2  	 (*(ioport volatile unsigned int *)0x301B)
#define RCERG2  	 (*(ioport volatile unsigned int *)0x301C)
#define RCERH2  	 (*(ioport volatile unsigned int *)0x301D)
#define XCERG2  	 (*(ioport volatile unsigned int *)0x301E)
#define XCERH2  	 (*(ioport volatile unsigned int *)0x301F)

#define	DRR12_ADDR	 0x003000
#define	DRR22_ADDR	 0x003001
#define	DXR12_ADDR	 0x003002
#define	DXR22_ADDR	 0x003003

#endif


/*----------------------------------------------------------
 * DMA global registers
 *----------------------------------------------------------*/
#if (VC5503 || VC5507 || VC5509A || VC5510)
#define DMAGCR		 (*(ioport volatile unsigned int *)0x0e00)
#define DMAGSCR		 (*(ioport volatile unsigned int *)0x0e02)
#define DMAGTCR		 (*(ioport volatile unsigned int *)0x0e03)
#endif

#if (VC5501 || VC5502)
#define DMAGCR		 (*(ioport volatile unsigned int *)0x0e00)
#define DMAGTCR		 (*(ioport volatile unsigned int *)0x0e01)
#endif
/*----------------------------------------------------------
 * DMA registers
 *----------------------------------------------------------*/
/*--- DMA0 ---*/
#define DMACSDP0	 (*(ioport volatile unsigned int *)0x0c00)
#define DMACCR0		 (*(ioport volatile unsigned int *)0x0c01)
#define DMACICR0	 (*(ioport volatile unsigned int *)0x0c02)
#define DMACSR0		 (*(ioport volatile unsigned int *)0x0c03)
#define DMACSSA0L	 (*(ioport volatile unsigned int *)0x0c04)
#define DMACSSA0U	 (*(ioport volatile unsigned int *)0x0c05)
#define DMACDSA0L	 (*(ioport volatile unsigned int *)0x0c06)
#define DMACDSA0U	 (*(ioport volatile unsigned int *)0x0c07)
#define DMACEN0		 (*(ioport volatile unsigned int *)0x0c08)
#define DMACFN0		 (*(ioport volatile unsigned int *)0x0c09)
#define DMACSFI0	 (*(ioport volatile unsigned int *)0x0c0a)
#define DMACSEI0	 (*(ioport volatile unsigned int *)0x0c0b)
#define DMACSAC0	 (*(ioport volatile unsigned int *)0x0c0c)
#define DMACDAC0	 (*(ioport volatile unsigned int *)0x0c0d)
#define DMACDEI0	 (*(ioport volatile unsigned int *)0x0c0e)
#define DMACDFI0	 (*(ioport volatile unsigned int *)0x0c0f)

/*--- DMA1 ---*/
#define DMACSDP1	 (*(ioport volatile unsigned int *)0x0c20)
#define DMACCR1		 (*(ioport volatile unsigned int *)0x0c21)
#define DMACICR1	 (*(ioport volatile unsigned int *)0x0c22)
#define DMACSR1		 (*(ioport volatile unsigned int *)0x0c23)
#define DMACSSA1L	 (*(ioport volatile unsigned int *)0x0c24)
#define DMACSSA1U	 (*(ioport volatile unsigned int *)0x0c25)
#define DMACDSA1L	 (*(ioport volatile unsigned int *)0x0c26)
#define DMACDSA1U	 (*(ioport volatile unsigned int *)0x0c27)
#define DMACEN1		 (*(ioport volatile unsigned int *)0x0c28)
#define DMACFN1		 (*(ioport volatile unsigned int *)0x0c29)
#define DMACSFI1	 (*(ioport volatile unsigned int *)0x0c2a)
#define DMACSEI1	 (*(ioport volatile unsigned int *)0x0c2b)
#define DMACSAC1	 (*(ioport volatile unsigned int *)0x0c2c)
#define DMACDAC1	 (*(ioport volatile unsigned int *)0x0c2d)
#define DMACDEI1	 (*(ioport volatile unsigned int *)0x0c2e)
#define DMACDFI1	 (*(ioport volatile unsigned int *)0x0c2f)

/*--- DMA2 ---*/
#define DMACSDP2	 (*(ioport volatile unsigned int *)0x0c40)
#define DMACCR2		 (*(ioport volatile unsigned int *)0x0c41)
#define DMACICR2	 (*(ioport volatile unsigned int *)0x0c42)
#define DMACSR2		 (*(ioport volatile unsigned int *)0x0c43)
#define DMACSSA2L	 (*(ioport volatile unsigned int *)0x0c44)
#define DMACSSA2U	 (*(ioport volatile unsigned int *)0x0c45)
#define DMACDSA2L	 (*(ioport volatile unsigned int *)0x0c46)
#define DMACDSA2U	 (*(ioport volatile unsigned int *)0x0c47)
#define DMACEN2		 (*(ioport volatile unsigned int *)0x0c48)
#define DMACFN2		 (*(ioport volatile unsigned int *)0x0c49)
#define DMACSFI2	 (*(ioport volatile unsigned int *)0x0c4a)
#define DMACSEI2	 (*(ioport volatile unsigned int *)0x0c4b)
#define DMACSAC2	 (*(ioport volatile unsigned int *)0x0c4c)
#define DMACDAC2	 (*(ioport volatile unsigned int *)0x0c4d)
#define DMACDEI2	 (*(ioport volatile unsigned int *)0x0c4e)
#define DMACDFI2	 (*(ioport volatile unsigned int *)0x0c4f)

/*--- DMA3 ---*/
#define DMACSDP3	 (*(ioport volatile unsigned int *)0x0c60)
#define DMACCR3		 (*(ioport volatile unsigned int *)0x0c61)
#define DMACICR3	 (*(ioport volatile unsigned int *)0x0c62)
#define DMACSR3		 (*(ioport volatile unsigned int *)0x0c63)
#define DMACSSA3L	 (*(ioport volatile unsigned int *)0x0c64)
#define DMACSSA3U	 (*(ioport volatile unsigned int *)0x0c65)
#define DMACDSA3L	 (*(ioport volatile unsigned int *)0x0c66)
#define DMACDSA3U	 (*(ioport volatile unsigned int *)0x0c67)
#define DMACEN3		 (*(ioport volatile unsigned int *)0x0c68)
#define DMACFN3		 (*(ioport volatile unsigned int *)0x0c69)
#define DMACSFI3	 (*(ioport volatile unsigned int *)0x0c6a)
#define DMACSEI3	 (*(ioport volatile unsigned int *)0x0c6b)
#define DMACSAC3	 (*(ioport volatile unsigned int *)0x0c6c)
#define DMACDAC3	 (*(ioport volatile unsigned int *)0x0c6d)
#define DMACDEI3	 (*(ioport volatile unsigned int *)0x0c6e)
#define DMACDFI3	 (*(ioport volatile unsigned int *)0x0c6f)

/*--- DMA4 ---*/
#define DMACSDP4	 (*(ioport volatile unsigned int *)0x0c80)
#define DMACCR4		 (*(ioport volatile unsigned int *)0x0c81)
#define DMACICR4	 (*(ioport volatile unsigned int *)0x0c82)
#define DMACSR4		 (*(ioport volatile unsigned int *)0x0c83)
#define DMACSSA4L	 (*(ioport volatile unsigned int *)0x0c84)
#define DMACSSA4U	 (*(ioport volatile unsigned int *)0x0c85)
#define DMACDSA4L	 (*(ioport volatile unsigned int *)0x0c86)
#define DMACDSA4U	 (*(ioport volatile unsigned int *)0x0c87)
#define DMACEN4		 (*(ioport volatile unsigned int *)0x0c88)
#define DMACFN4		 (*(ioport volatile unsigned int *)0x0c89)
#define DMACSFI4	 (*(ioport volatile unsigned int *)0x0c8a)
#define DMACSEI4	 (*(ioport volatile unsigned int *)0x0c8b)
#define DMACSAC4	 (*(ioport volatile unsigned int *)0x0c8c)
#define DMACDAC4	 (*(ioport volatile unsigned int *)0x0c8d)
#define DMACDEI4	 (*(ioport volatile unsigned int *)0x0c8e)
#define DMACDFI4	 (*(ioport volatile unsigned int *)0x0c8f)

/*--- DMA5 ---*/
#define DMACSDP5	 (*(ioport volatile unsigned int *)0x0ca0)
#define DMACCR5		 (*(ioport volatile unsigned int *)0x0ca1)
#define DMACICR5	 (*(ioport volatile unsigned int *)0x0ca2)
#define DMACSR5		 (*(ioport volatile unsigned int *)0x0ca3)
#define DMACSSA5L	 (*(ioport volatile unsigned int *)0x0ca4)
#define DMACSSA5U	 (*(ioport volatile unsigned int *)0x0ca5)
#define DMACDSA5L	 (*(ioport volatile unsigned int *)0x0ca6)
#define DMACDSA5U	 (*(ioport volatile unsigned int *)0x0ca7)
#define DMACEN5		 (*(ioport volatile unsigned int *)0x0ca8)
#define DMACFN5		 (*(ioport volatile unsigned int *)0x0ca9)
#define DMACSFI5	 (*(ioport volatile unsigned int *)0x0caa)
#define DMACSEI5	 (*(ioport volatile unsigned int *)0x0cab)
#define DMACSAC5	 (*(ioport volatile unsigned int *)0x0cac)
#define DMACDAC5	 (*(ioport volatile unsigned int *)0x0cad)
#define DMACDEI5	 (*(ioport volatile unsigned int *)0x0cae)
#define DMACDFI5	 (*(ioport volatile unsigned int *)0x0caf)

/*----------------------------------------------------------
 * EMIF registers
 *----------------------------------------------------------*/
/*----------------------------*/
/*----- VC5503/07/09A/10 -----*/
/*----------------------------*/
#if (VC5503 || VC5507 || VC5509A || VC5510)
#define EMIF_EGCR	 (*(ioport volatile unsigned int *)0x0800)
#define EMIF_EMI_RST (*(ioport volatile unsigned int *)0x0801)
#define EMIF_EMI_BE	 (*(ioport volatile unsigned int *)0x0802)
#define EMIF_CE0_1	 (*(ioport volatile unsigned int *)0x0803)
#define EMIF_CE0_2	 (*(ioport volatile unsigned int *)0x0804)
#define EMIF_CE0_3	 (*(ioport volatile unsigned int *)0x0805)
#define EMIF_CE1_1	 (*(ioport volatile unsigned int *)0x0806)
#define EMIF_CE1_2	 (*(ioport volatile unsigned int *)0x0807)
#define EMIF_CE1_3	 (*(ioport volatile unsigned int *)0x0808)
#define EMIF_CE2_1	 (*(ioport volatile unsigned int *)0x0809)
#define EMIF_CE2_2	 (*(ioport volatile unsigned int *)0x080A)
#define EMIF_CE2_3	 (*(ioport volatile unsigned int *)0x080B)
#define EMIF_CE3_1	 (*(ioport volatile unsigned int *)0x080C)
#define EMIF_CE3_2	 (*(ioport volatile unsigned int *)0x080D)
#define EMIF_CE3_3	 (*(ioport volatile unsigned int *)0x080E)
#define EMIF_SDC1	 (*(ioport volatile unsigned int *)0x080F)
#define EMIF_SDPER	 (*(ioport volatile unsigned int *)0x0810)
#define EMIF_SDCNT	 (*(ioport volatile unsigned int *)0x0811)
#define EMIF_INIT	 (*(ioport volatile unsigned int *)0x0812)
#define EMIF_SDC2	 (*(ioport volatile unsigned int *)0x0813)
#endif

#if (VC5503|| VC5507 || VC5509A)
#define EMIF_SDC3	 (*(ioport volatile unsigned int *)0x0814)
#endif

/*-------------------------*/
/*----- VC5501/02 ---------*/
/*-------------------------*/
#if (VC5501 || VC5502)
#define EMIF_EGCR1	 (*(ioport volatile unsigned int *)0x0800)
#define EMIF_EGCR2	 (*(ioport volatile unsigned int *)0x0801)
#define EMIF_CE1_1	 (*(ioport volatile unsigned int *)0x0802)
#define EMIF_CE1_2	 (*(ioport volatile unsigned int *)0x0803)
#define EMIF_CE0_1	 (*(ioport volatile unsigned int *)0x0804)
#define EMIF_CE0_2	 (*(ioport volatile unsigned int *)0x0805)

#define EMIF_CE2_1	 (*(ioport volatile unsigned int *)0x0808)
#define EMIF_CE2_2	 (*(ioport volatile unsigned int *)0x0809)
#define EMIF_CE3_1	 (*(ioport volatile unsigned int *)0x080A)
#define EMIF_CE3_2	 (*(ioport volatile unsigned int *)0x080B)
#define EMIF_SDC1	 (*(ioport volatile unsigned int *)0x080C)
#define EMIF_SDC2	 (*(ioport volatile unsigned int *)0x080D)
#define EMIF_SDRC1	 (*(ioport volatile unsigned int *)0x080E)
#define EMIF_SDRC2	 (*(ioport volatile unsigned int *)0x080F)
#define EMIF_SDX1	 (*(ioport volatile unsigned int *)0x0810)
#define EMIF_SDX2	 (*(ioport volatile unsigned int *)0x0811)

#define EMIF_CE1_SC1 (*(ioport volatile unsigned int *)0x0822)
#define EMIF_CE1_SC2 (*(ioport volatile unsigned int *)0x0823)
#define EMIF_CE0_SC1 (*(ioport volatile unsigned int *)0x0824)
#define EMIF_CE0_SC2 (*(ioport volatile unsigned int *)0x0825)

#define EMIF_CE2_SC1 (*(ioport volatile unsigned int *)0x0828)
#define EMIF_CE2_SC2 (*(ioport volatile unsigned int *)0x0829)
#define EMIF_CE3_SC1 (*(ioport volatile unsigned int *)0x082A)
#define EMIF_CE3_SC2 (*(ioport volatile unsigned int *)0x082B)

#define EMIF_CESCR1	 (*(ioport volatile unsigned int *)0x0840)
#define EMIF_CESCR2	 (*(ioport volatile unsigned int *)0x0841)

#endif

/*----------------------------------------------------------
 * GPIO registers
 *----------------------------------------------------------*/
#define	IODIR		 (*(ioport volatile unsigned int *)0x3400)
#define	IODATA		 (*(ioport volatile unsigned int *)0x3401)

/*----------------------------------------------------------
 * IDLE registers
 *----------------------------------------------------------*/
#define	ICR			 (*(ioport volatile unsigned int *)0x0001)
#define	ISTR		 (*(ioport volatile unsigned int *)0x0002)

/*----------------------------------------------------------
 * PLL registers
 *----------------------------------------------------------*/
#if (VC5503 || VC5507 || VC5509A || VC5510)
#define CLKMD		 (*(ioport volatile unsigned int *)0x1C00)
#endif

#if (VC5501 || VC5502)
#define CLKMD		 (*(ioport volatile unsigned int *)0x8C00)
#define PLLCSR		 (*(ioport volatile unsigned int *)0x1C80)
#define CK3SEL		 (*(ioport volatile unsigned int *)0x1C82)
#define PLLM		 (*(ioport volatile unsigned int *)0x1C88)
#define PLLDIV0		 (*(ioport volatile unsigned int *)0x1C8A)
#define PLLDIV1		 (*(ioport volatile unsigned int *)0x1C8C)
#define PLLDIV2		 (*(ioport volatile unsigned int *)0x1C8E)
#define PLLDIV3		 (*(ioport volatile unsigned int *)0x1C90)
#define OSCDIV1		 (*(ioport volatile unsigned int *)0x1C92)
#define WKEN		 (*(ioport volatile unsigned int *)0x1C98)
#define CLKOUTSR	 (*(ioport volatile unsigned int *)0x8400)
#endif

/*----------------------------------------------------------
 * Timer & WDT registers
 *----------------------------------------------------------*/
/*----------------------------------*/
/*----- VC5503/07/09A/5510 ---------*/
/*----------------------------------*/
#if (VC5503 || VC5507 || VC5509A || VC5510)
/*--- Timer0 ---*/
#define TIM0		 (*(ioport volatile unsigned int *)0x1000)
#define PRD0		 (*(ioport volatile unsigned int *)0x1001)
#define TCR0		 (*(ioport volatile unsigned int *)0x1002)
#define PRSC0		 (*(ioport volatile unsigned int *)0x1003)
/*--- Timer1 ---*/
#define TIM1		 (*(ioport volatile unsigned int *)0x2400)
#define PRD1		 (*(ioport volatile unsigned int *)0x2401)
#define TCR1		 (*(ioport volatile unsigned int *)0x2402)
#define PRSC1		 (*(ioport volatile unsigned int *)0x2403)
#endif

#if (VC5503 || VC5507 || VC5509A)
/*--- Watch Dog Timer ---*/
#define WDTIM		 (*(ioport volatile unsigned int *)0x4000)
#define WDPRD		 (*(ioport volatile unsigned int *)0x4001)
#define WDTCR		 (*(ioport volatile unsigned int *)0x4002)
#define WDTCR2		 (*(ioport volatile unsigned int *)0x4003)

#endif
/*-------------------------*/
/*----- VC5501/02 ---------*/
/*-------------------------*/
#if (VC5501 || VC5502)
#define TSSR		 (*(ioport volatile unsigned int *)0x8000)

/*--- Timer0 ---*/
#define GPTPID1_0	 (*(ioport volatile unsigned int *)0x1000)
#define GPTPID2_0	 (*(ioport volatile unsigned int *)0x1001)
#define GPTEMU_0	 (*(ioport volatile unsigned int *)0x1002)
#define GPTCLK_0	 (*(ioport volatile unsigned int *)0x1003)
#define GPTGPINT_0	 (*(ioport volatile unsigned int *)0x1004)
#define GPTGPEN_0	 (*(ioport volatile unsigned int *)0x1005)
#define GPTGPDAT_0	 (*(ioport volatile unsigned int *)0x1006)
#define GPTGPDIR_0	 (*(ioport volatile unsigned int *)0x1007)
#define GPTCNT1_0	 (*(ioport volatile unsigned int *)0x1008)
#define GPTCNT2_0	 (*(ioport volatile unsigned int *)0x1009)
#define GPTCNT3_0	 (*(ioport volatile unsigned int *)0x100A)
#define GPTCNT4_0	 (*(ioport volatile unsigned int *)0x100B)
#define GPTPRD1_0	 (*(ioport volatile unsigned int *)0x100C)
#define GPTPRD2_0	 (*(ioport volatile unsigned int *)0x100D)
#define GPTPRD3_0	 (*(ioport volatile unsigned int *)0x100E)
#define GPTPRD4_0	 (*(ioport volatile unsigned int *)0x100F)
#define GPTCTL1_0	 (*(ioport volatile unsigned int *)0x1010)
#define GPTCTL2_0	 (*(ioport volatile unsigned int *)0x1011)
#define GPTGCTL1_0	 (*(ioport volatile unsigned int *)0x1012)

/*--- Timer1 ---*/
#define GPTPID1_1	 (*(ioport volatile unsigned int *)0x2400)
#define GPTPID2_1	 (*(ioport volatile unsigned int *)0x2401)
#define GPTEMU_1	 (*(ioport volatile unsigned int *)0x2402)
#define GPTCLK_1	 (*(ioport volatile unsigned int *)0x2403)
#define GPTGPINT_1	 (*(ioport volatile unsigned int *)0x2404)
#define GPTGPEN_1	 (*(ioport volatile unsigned int *)0x2405)
#define GPTGPDAT_1	 (*(ioport volatile unsigned int *)0x2406)
#define GPTGPDIR_1	 (*(ioport volatile unsigned int *)0x2407)
#define GPTCNT1_1	 (*(ioport volatile unsigned int *)0x2408)
#define GPTCNT2_1	 (*(ioport volatile unsigned int *)0x2409)
#define GPTCNT3_1	 (*(ioport volatile unsigned int *)0x240A)
#define GPTCNT4_1	 (*(ioport volatile unsigned int *)0x240B)
#define GPTPRD1_1	 (*(ioport volatile unsigned int *)0x240C)
#define GPTPRD2_1	 (*(ioport volatile unsigned int *)0x240D)
#define GPTPRD3_1	 (*(ioport volatile unsigned int *)0x240E)
#define GPTPRD4_1	 (*(ioport volatile unsigned int *)0x240F)
#define GPTCTL1_1	 (*(ioport volatile unsigned int *)0x2410)
#define GPTCTL2_1	 (*(ioport volatile unsigned int *)0x2411)
#define GPTGCTL1_1	 (*(ioport volatile unsigned int *)0x2412)

/*--- Watch Dog Timer ---*/
#define WDTPID1		 (*(ioport volatile unsigned int *)0x4000)
#define WDTPID2		 (*(ioport volatile unsigned int *)0x4001)
#define WDTEMU		 (*(ioport volatile unsigned int *)0x4002)
#define WDTCLK		 (*(ioport volatile unsigned int *)0x4003)
#define WDTGPINT	 (*(ioport volatile unsigned int *)0x4004)
#define WDTGPEN		 (*(ioport volatile unsigned int *)0x4005)
#define WDTGPDAT	 (*(ioport volatile unsigned int *)0x4006)
#define WDTGPDIR	 (*(ioport volatile unsigned int *)0x4007)
#define WDTCNT1		 (*(ioport volatile unsigned int *)0x4008)
#define WDTCNT2		 (*(ioport volatile unsigned int *)0x4009)
#define WDTCNT3		 (*(ioport volatile unsigned int *)0x400A)
#define WDTCNT4		 (*(ioport volatile unsigned int *)0x400B)
#define WDTPRD1		 (*(ioport volatile unsigned int *)0x400C)
#define WDTPRD2		 (*(ioport volatile unsigned int *)0x400D)
#define WDTPRD3		 (*(ioport volatile unsigned int *)0x400E)
#define WDTPRD4		 (*(ioport volatile unsigned int *)0x400F)
#define WDTCTL1		 (*(ioport volatile unsigned int *)0x4010)
#define WDTCTL2		 (*(ioport volatile unsigned int *)0x4011)
#define WDTGCTL1	 (*(ioport volatile unsigned int *)0x4012)
#define WDTWCTL1	 (*(ioport volatile unsigned int *)0x4014)
#define WDTWCTL2	 (*(ioport volatile unsigned int *)0x4015)

#endif

/*----------------------------------------------------------
 * miscellaneous
 *----------------------------------------------------------*/
/*------------------------*/
/*----- BUS select etc ---*/
/*------------------------*/
#if (VC5503 || VC5507 || VC5509A)
#define SYSR		 (*(ioport volatile unsigned int *)0x07FD)
#define EBSR		 (*(ioport volatile unsigned int *)0x6C00)
#endif

#if (VC5501 || VC5502)
#define XBSR		 (*(ioport volatile unsigned int *)0x6C00)
		// Bus selection register
#define XBCR		 (*(ioport volatile unsigned int *)0x8800)
		// enable IO pin pullup/pulldown
#endif


/*-------------------------------*/
/*----- VC5503/07/09A RTC    ----*/
/*-------------------------------*/
#if (VC5503 || VC5507 || VC5509A)
#define RTCSEC		 (*(ioport volatile unsigned int *)0x1800)
#define RTCSECA		 (*(ioport volatile unsigned int *)0x1801)
#define RTCMIN		 (*(ioport volatile unsigned int *)0x1802)
#define RTCMINA		 (*(ioport volatile unsigned int *)0x1803)
#define RTCHOUR		 (*(ioport volatile unsigned int *)0x1804)
#define RTCHOURA	 (*(ioport volatile unsigned int *)0x1805)
#define RTCDAYW		 (*(ioport volatile unsigned int *)0x1806)
#define RTCDAYM		 (*(ioport volatile unsigned int *)0x1807)
#define RTCMONTH	 (*(ioport volatile unsigned int *)0x1808)
#define RTCYEAR		 (*(ioport volatile unsigned int *)0x1809)
#define RTCPINTR	 (*(ioport volatile unsigned int *)0x180A)
#define RTCINTEN	 (*(ioport volatile unsigned int *)0x180B)
#define RTCINTFL	 (*(ioport volatile unsigned int *)0x180C)
#endif

/*----------------------------*/
/*----- VC5507/09A ADC    ----*/
/*----------------------------*/
#if (VC5507 || VC5509A)
#define ADCCTL		 (*(ioport volatile unsigned int *)0x6800)
#define ADCDATA		 (*(ioport volatile unsigned int *)0x6801)
#define ADCCLKDIV	 (*(ioport volatile unsigned int *)0x6802)
#define ADCCLKCTL	 (*(ioport volatile unsigned int *)0x6803)
#endif

/*----------------------------------*/
/*----- VC5501/02/03/07/09A I2C ----*/
/*----------------------------------*/
#if (VC5501 || VC5502)
#define I2COAR		 (*(ioport volatile unsigned int *)0x3C00)
#define I2CIER		 (*(ioport volatile unsigned int *)0x3C01)
#define I2CSTR		 (*(ioport volatile unsigned int *)0x3C02)
#define I2CCLKL		 (*(ioport volatile unsigned int *)0x3C03)
#define I2CCLKH		 (*(ioport volatile unsigned int *)0x3C04)
#define I2CCNT		 (*(ioport volatile unsigned int *)0x3C05)
#define I2CDRR		 (*(ioport volatile unsigned int *)0x3C06)
#define I2CSAR		 (*(ioport volatile unsigned int *)0x3C07)
#define I2CDXR		 (*(ioport volatile unsigned int *)0x3C08)
#define I2CMDR		 (*(ioport volatile unsigned int *)0x3C09)
#define I2CISRC		 (*(ioport volatile unsigned int *)0x3C0A)
#define I2CGPIO		 (*(ioport volatile unsigned int *)0x3C0B)
#define I2CPSC		 (*(ioport volatile unsigned int *)0x3C0C)
#define I2CPID1		 (*(ioport volatile unsigned int *)0x3C0D)
#define I2CPID2		 (*(ioport volatile unsigned int *)0x3C0E)
#endif

#if (VC5503 || VC5507 || VC5509A)
#define I2COAR		 (*(ioport volatile unsigned int *)0x3C00)
#define I2CIMR		 (*(ioport volatile unsigned int *)0x3C01)
#define I2CSTR		 (*(ioport volatile unsigned int *)0x3C02)
#define I2CCLKL		 (*(ioport volatile unsigned int *)0x3C03)
#define I2CCLKH		 (*(ioport volatile unsigned int *)0x3C04)
#define I2CCNT		 (*(ioport volatile unsigned int *)0x3C05)
#define I2CDRR		 (*(ioport volatile unsigned int *)0x3C06)
#define I2CSAR		 (*(ioport volatile unsigned int *)0x3C07)
#define I2CDXR		 (*(ioport volatile unsigned int *)0x3C08)
#define I2CMDR		 (*(ioport volatile unsigned int *)0x3C09)
#define I2CIVR		 (*(ioport volatile unsigned int *)0x3C0A)
#define I2CPSC		 (*(ioport volatile unsigned int *)0x3C0C)
#define I2CMDR2		 (*(ioport volatile unsigned int *)0x3C0F)
#endif

/*-------------------------*/
/*----- VC5501/02 UART-----*/
/*-------------------------*/
#if (VC5501 || VC5502)
#define	URRBR		 (*(ioport volatile unsigned int *)0x9c00)
#define	URTHR		 (*(ioport volatile unsigned int *)0x9c00)
#define	URIER		 (*(ioport volatile unsigned int *)0x9c01)
#define	URIIR		 (*(ioport volatile unsigned int *)0x9c02)
#define	URFCR		 (*(ioport volatile unsigned int *)0x9c02)
#define	URLCR		 (*(ioport volatile unsigned int *)0x9c03)
#define	URMCR		 (*(ioport volatile unsigned int *)0x9c04)
#define	URLSR		 (*(ioport volatile unsigned int *)0x9c05)
#define	URSCR		 (*(ioport volatile unsigned int *)0x9c07)
#define	URDLL		 (*(ioport volatile unsigned int *)0x9c08)
#define	URDLM		 (*(ioport volatile unsigned int *)0x9c09)
#define	URPID1		 (*(ioport volatile unsigned int *)0x9c0a)
#define	URPID2		 (*(ioport volatile unsigned int *)0x9c0b)
#define	URPECR		 (*(ioport volatile unsigned int *)0x9c0c)
#endif

/*-------------------------*/
/*----- VC5501/02 Idle-----*/
/*-------------------------*/
#if (VC5501 || VC5502)
#define	PICR		 (*(ioport volatile unsigned int *)0x9400)
#define	PISTR		 (*(ioport volatile unsigned int *)0x9401)
#define	MICR		 (*(ioport volatile unsigned int *)0x9402)
#define	MISR		 (*(ioport volatile unsigned int *)0x9403)
#endif


